GpuError

Enum GpuError 

#[non_exhaustive]
pub enum GpuError { NoDevice, BackendUnavailable(String), AllocationFailed { requested: u64, device_max: u64, }, ShaderCompilation(String), MissingEntryPoint { name: String, }, Dispatch(String), ReadbackTimeout { ms: u64, }, BindingMismatch { expected: usize, got: usize, }, Backend { op: BackendOp, detail: String, }, }
Errors that can occur during GPU operations.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


NoDevice

No suitable GPU device was found on this system.



BackendUnavailable(String)

The requested backend is not available (e.g. Vulkan not installed).



AllocationFailed

Buffer allocation failed — typically the device ran out of memory.

Fields

requested: u64

Bytes requested.

device_max: u64

Device maximum allocation size.



ShaderCompilation(String)

Shader compilation failed.



MissingEntryPoint

Shader is missing an entry point with the expected name.

Fields

name: String

The entry point name that was expected.



Dispatch(String)

A dispatch or readback operation failed.



ReadbackTimeout

Readback from GPU buffer to CPU timed out.

Fields

ms: u64

Timeout duration in milliseconds.



BindingMismatch

The provided buffer count does not match the shader’s binding count.

Fields

expected: usize

Bindings declared in the shader.

got: usize

Buffers provided by the caller.



Backend

Internal backend error (Vulkan, Metal, etc.).

Fields

op: BackendOp

The operation that failed.

detail: String

Human-readable detail string.